Portfolio Margin Endpoints
==========================

Portfolio Margin Account (USER_DATA)
------------------------------------
.. autofunction:: binance.spot.Spot.portfolio_margin_account

Portfolio Margin Collateral Rate (MARKET_DATA)
----------------------------------------------
.. autofunction:: binance.spot.Spot.portfolio_margin_collateral_rate

Portfolio Margin Pro Tiered Collateral Rate (USER_DATA)
-------------------------------------------------------
.. autofunction:: binance.spot.Spot.portfolio_margin_tiered_collateral_rate

Portfolio Margin Bankruptcy Loan Amount (USER_DATA)
---------------------------------------------------
.. autofunction:: binance.spot.Spot.portfolio_margin_bankruptcy_loan_amount

Portfolio Margin Bankruptcy Loan Repay (USER_DATA)
--------------------------------------------------
.. autofunction:: binance.spot.Spot.portfolio_margin_bankruptcy_loan_repay

Query Classic Portfolio Margin Negative Balance Interest History (USER_DATA)
----------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.query_classic_portfolio_margin_negative_balance_interest_history

Get Portfolio Margin Pro SPAN Account Info (USER_DATA)
------------------------------------------------------
.. autofunction:: binance.spot.Spot.get_portfolio_margin_span_account_info

Get Portfolio Margin Pro Account Balance (USER_DATA)
----------------------------------------------------
.. autofunction:: binance.spot.Spot.get_portfolio_margin_account_balance

Query Portfolio Margin Asset Index Price (MARKET_DATA)
------------------------------------------------------
.. autofunction:: binance.spot.Spot.query_portfolio_margin_asset_index_price

Fund Auto-collection (USER_DATA)
--------------------------------
.. autofunction:: binance.spot.Spot.fund_auto_collection

BNB Transfer (USER_DATA)
------------------------
.. autofunction:: binance.spot.Spot.bnb_transfer

Change Auto-repay-futures Status (USER_DATA)
--------------------------------------------
.. autofunction:: binance.spot.Spot.change_auto_repay_futures_status

Get Auto-repay-futures Status (USER_DATA)
-----------------------------------------
.. autofunction:: binance.spot.Spot.get_auto_repay_futures_status

Repay futures Negative Balance (USER_DATA)
------------------------------------------
.. autofunction:: binance.spot.Spot.repay_futures_negative_balance

Fund Collection by Asset (USER_DATA)
------------------------------------
.. autofunction:: binance.spot.Spot.fund_collection_by_asset
